@@ -3,8 +3,8 @@ use Mojo::Base 'Ado::Command';
 use Getopt::Long qw(GetOptionsFromArray :config no_auto_abbrev no_ignore_case);
 
 has description => "Generates minimal Apache2 Virtual Host configuration file.\n";
-has usage       => sub { shift->extract_usage };
-has args        => sub { {} };
+has usage => sub { shift->extract_usage };
+
 my $IS_DOS = ($^O eq 'MSWin32' or $^O eq 'dos' or $^O eq 'os2');
 
 sub run {
@@ -195,6 +195,7 @@ Run this command. Returns C<$self>.
 
 L<Apache deployment|https://github.com/kraih/mojo/wiki/Apache-deployment>,
 L<Apache - Upgrading to 2.4 from 2.2|http://httpd.apache.org/docs/2.4/upgrading.html>,
+L<Mojolicious::Guides::Cookbook>,
 L<Ado::Command::generate::apache2htaccess>,
 L<Mojolicious::Command::generate>, L<Getopt::Long>,
 L<Ado::Command> L<Ado::Manual>,
