@@ -59,13 +59,41 @@ sub _get_plugin_config {
 
 #plugin configuration getter
 sub config {
-    my ($self, $key) = @_;
+    my ($self, $key, $value) = @_;
     $self->{config} //= $self->_get_plugin_config();
+    if (defined $value) {
+        $self->{config}->{$key} = $value;
+        return $self->{config};
+    }
     return $key
       ? $self->{config}->{$key}
       : $self->{config};
 }
 
+# one place for initialising plugins in register()
+sub initialise {
+    my ($self, $app, $conf) = @_;
+    return if $self->{_initialised};
+    $self->app($app);    #!Needed in $self->config!
+    state $mode = $app->mode;
+
+    #Merge passed configuration with configuration
+    #from  etc/ado.conf and etc/plugins/$name.conf
+    for my $k (keys %$conf) { $self->config($k => $conf->{$k}); }
+    $conf = $self->config;
+    $app->log->debug('Plugin ' . $self->name . ' configuration:' . $app->dumper($conf))
+      if ($mode eq 'development');
+
+    # Add namespaces if defined.
+    push @{$app->routes->namespaces}, @{$conf->{namespaces}}
+      if @{$conf->{namespaces} || []};
+
+    # Load routes if defined.
+    $app->load_routes($conf->{routes}) if (@{$conf->{routes} || []});
+    $self->{_initialised} = 1;
+    return ($self, $app, $conf);
+}
+
 1;
 
 =pod
@@ -79,19 +107,22 @@ Ado::Plugin - base class for Ado specific plugins.
 
 =head1 SYNOPSIS
 
-  # CamelCase plugin name
+Create your plugin like this:
+
+  # CamelCase plugin name is recommended.
   package Ado::Plugin::MyPlugin;
   use Mojo::Base 'Ado::Plugin';
 
   sub register {
-    my ($self, $app, $conf) = @_;
-    $self->app($app);#!Needed in $self->config!
-    #Merge passed configuration with plugin configuration from files 
-    #from  etc/ado.conf and etc/plugins/my_plugin.conf
-    $conf = {%{$self->config},%{$conf?$conf:{}}};
-    # Your magic here! 
+    my ($self, $app, $conf) = shift->initialise(@_);
+    
+    # Your magic here!.. 
+    
+    return $self;
   }
 
+but better use L<Ado::Command::generate::adoplugin> to do everything for you.
+
 
 =head1 DESCRIPTION
 
@@ -128,6 +159,8 @@ The default mapping is:
         pl   => 'Mojolicious::Plugin::Config'
     };
 
+Using this attribute you can use your own configuration plugin as far as it supports the L<Mojolicious::Plugin::Config> API.
+
 =head2 ext
 
 Extension used for the plugin specific configuration file. defaults to 'conf';
@@ -140,33 +173,55 @@ The name - only the last word of the plugin's package name.
 
   $self->name # MyPlugin
 
-
-
 =head1 METHODS
 
-
 Ado::Plugin provides the following methods for use by subclasses.
 
 =head2 config
 
-The configuration which is for the plugin only.
+The configuration which is for the currently registering plugin only.
+In L<Ado> every plugin can have its own configuration file.
+When calling this method for the first time it will parse and merge
+configuration files for the plugin. Options from mode specific 
+configuration file will overwrite options form the generic file.
+You usually do not need to invoke this method directly since it is 
+invoked in L</initialise>.
 
-  $self->config 
-  #everything in '$ENV{MOJO_HOME}/etc/plugins/'.decamelize('MyPlugin').'.conf'
-  #or under  $app->config('MyPlugin') 
-  #or $app->config('my_plugin') - in this order
+  # everything in '$ENV{MOJO_HOME}/etc/plugins/$my_plugin.conf'
+  # and/or   '$ENV{MOJO_HOME}/etc/plugins/$my_plugin.$mode.conf'
+  my $config = $self->config; 
   
+  #get a config value
   my $value = $self->config('key');
+  #set
+  my $config = $self->config(foo => 'bar');
 
+=head2 initialise
 
-=head1 SPONSORS
+Used to initialise you plugin and reduce boilerplate code. 
+
+  * Merges configurations.
+  * Adds new $app->routes->namespaces if defined in config.
+  * Loads routes if defined in config
+  * Returns ($self, $app, $config).
+
+  sub register {
+    my ($self, $app, $conf) = @_;
+    $self->initialise($app, $conf);
+    # ...
+  
+This method 
+should be the first invoked in your L<Mojolicious::Plugin/register> method. 
+If you need to do some very custom stuff, you are free to implement the
+initialisation yourself.
 
-The original author
 
 =head1 SEE ALSO
 
-L<Ado::Manual::Plugins>, L<Ado::Plugin::Routes>, L<Mojolicious::Plugin>
-
+L<Ado::Manual::Plugins>, L<Mojolicious::Plugin>,
+L<Ado::Plugin::AdoHelpers>, L<Ado::Plugin::Auth>, L<Ado::Plugin::I18n>,
+L<Ado::Plugin::MarkdownRenderer>, L<Ado::Plugin::Routes>, 
+L<Ado::Command::generate::adoplugin>.
 
 =head1 AUTHOR
 
@@ -186,5 +241,3 @@ the license may release under a different license.
 See http://opensource.org/licenses/lgpl-3.0.html for more information.
 
 =cut
-
-
